@@ -70,7 +70,7 @@ class LambdaToSsmstringparameter(
         :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_string_parameter_obj: Existing instance of SSM String parameter object, If this is set then the stringParameterProps is ignored. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default properties are used.
         :param string_parameter_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the parameter. Default: - SSM_STRING_PARAMETER_NAME
         :param string_parameter_permissions: Optional SSM String parameter permissions to grant to the Lambda function. One of the following may be specified: "Read", "ReadWrite". Default: - Read access is given to the Lambda function if no value is specified.
         :param string_parameter_props: Optional user provided props to override the default props for SSM String parameter. If existingStringParameterObj is not set stringParameterProps is required. The only supported string parameter type is ParameterType.STRING. Default: - Default props are used
@@ -148,7 +148,7 @@ class LambdaToSsmstringparameterProps:
         :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_string_parameter_obj: Existing instance of SSM String parameter object, If this is set then the stringParameterProps is ignored. Default: - Default props are used
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default properties are used.
         :param string_parameter_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the parameter. Default: - SSM_STRING_PARAMETER_NAME
         :param string_parameter_permissions: Optional SSM String parameter permissions to grant to the Lambda function. One of the following may be specified: "Read", "ReadWrite". Default: - Read access is given to the Lambda function if no value is specified.
         :param string_parameter_props: Optional user provided props to override the default props for SSM String parameter. If existingStringParameterObj is not set stringParameterProps is required. The only supported string parameter type is ParameterType.STRING. Default: - Default props are used
@@ -236,7 +236,8 @@ class LambdaToSsmstringparameterProps:
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''Optional - user provided props to override the default props for the Lambda function.
 
-        Providing both this and ``existingLambdaObj`` is an error.
+        Providing both this and ``existingLambdaObj``
+        causes an error.
 
         :default: - Default properties are used.
         '''
